<?php

/**
 * Back-end of Hoverbox_XH.
 *
 * PHP versions 4 and 5
 *
 * @category  CMSimple_XH
 * @author    ISEYE <info@iseye.de>
 * @copyright 2017 I.Sell <knollsen@gmx.net>
 * @version   1.7
 + @link      http://pluginxh.iseye.eu
 */

if (!defined('CMSIMPLE_XH_VERSION')) {
    header('HTTP/1.0 403 Forbidden');
    exit;
}

if (function_exists('XH_registerStandardPluginMenuItems')) {
    XH_registerStandardPluginMenuItems(true);
}


function Hoverbox_hsc($text) {
    if (function_exists('XH_hsc')) {
        return XH_hsc($text);
    } else {
        return htmlspecialchars($text, ENT_COMPAT, 'UTF-8');
    }
}

function Hoverbox_renderCsrfTokenInput() {
    global $_XH_csrfProtection;

    if (isset($_XH_csrfProtection)) {
        return $_XH_csrfProtection->tokenInput();
    } else {
        return '';
    }
}

function Hoverbox_checkCsrfToken() {
    global $_XH_csrfProtection;

    if (isset($_XH_csrfProtection)) {
        $_XH_csrfProtection->check();
    }
}

function Hoverbox_render($_template, $_bag) {
    global $pth, $cf;

    $_template = "{$pth['folder']['plugins']}hoverbox/views/$_template.htm";
    $_xhtml = $cf['xhtml']['endtags'];
    unset($pth, $cf);
    extract($_bag);
    ob_start();
    include $_template;
    $o = ob_get_clean();
    if (!$_xhtml) {
        $o = str_replace('/>', '>', $o);
    }
    return $o;
}

function Hoverbox_info() {
    global $pth, $tx, $plugin_tx, $_Hoverbox;

    $ptx = $plugin_tx['hoverbox'];
    $labels = array(
        'info' => $ptx['label_info'],
        'syscheck' => $ptx['syscheck_title'],
        'about' => $ptx['about'],
        'logo' => $ptx['alt_logo']
    );
    $labels = array_map('Hoverbox_hsc', $labels);
    $phpVersion = '4.3.0';
    foreach (array('ok', 'warn', 'fail') as $state) {
        $images[$state] = $pth['folder']['plugins']
            . "hoverbox/images/$state.png";
    }
    $checks = array();
    $checks[sprintf($ptx['syscheck_phpversion'], $phpVersion)]
        = version_compare(PHP_VERSION, $phpVersion) >= 0 ? 'ok' : 'fail';
    foreach (array('pcre') as $ext) {
        $checks[sprintf($ptx['syscheck_extension'], $ext)]
            = extension_loaded($ext) ? 'ok' : 'fail';
    }
    $checks[$ptx['syscheck_magic_quotes']]
        = !get_magic_quotes_runtime() ? 'ok' : 'fail';
    $checks[$ptx['syscheck_encoding']]
        = strtoupper($tx['meta']['codepage']) == 'UTF-8' ? 'ok' : 'warn';
    foreach (array('config/', 'css', 'languages/') as $folder) {
        $folders[] = $pth['folder']['plugins'] . 'hoverbox/' . $folder;
    }
    $folders[] = $_Hoverbox->getDataFolder();
    foreach ($folders as $folder) {
        $checks[sprintf($ptx['syscheck_writable'], $folder)]
            = is_writable($folder) ? 'ok' : 'warn';
    }
    $icon = $pth['folder']['plugins'] . 'hoverbox/help/isxh.png';
    $version = HOVERBOX_VERSION;
    $bag = compact('labels', 'images', 'checks', 'icon', 'version');
    return Hoverbox_render('info', $bag);
}

function Hoverbox_new($name) {
    global $e, $plugin_tx, $_Hoverbox;

    Hoverbox_checkCsrfToken();
    $ptx = $plugin_tx['hoverbox'];
    if (!$_Hoverbox->isValidName($name)) {
        $e .= '<li><b>' . $ptx['error_invalid_name'] . '</b>' . tag('br')
            . $name . '</li>' . PHP_EOL;
        return Hoverbox_admin();
    }
    $fn = $_Hoverbox->filename($name);
    if (!file_exists($fn)) {
        if ($_Hoverbox->write($name, '') !== false) {
            $qs = '?hoverbox&admin=plugin_main&action=edit&hoverbox_name='
                . $name;
            header('Location: ' . HOVERBOX_URL . $qs, true, 303);
            exit;
        } else {
            e('cntwriteto', 'file', $fn);
            return Hoverbox_admin();
        }
    } else {
        e('alreadyexists', 'file', $fn);
        return Hoverbox_admin();
    }
}

function Hoverbox_edit($name, $content = null) {
    global $sn, $pth, $cf, $tx, $_Hoverbox;

    if (!isset($content)) {
        $content = $_Hoverbox->read($name);
        if ($content === false) {
            e('cntopen', 'file', $_Hoverbox->filename($name));
            return false;
        }
    }
    $labels = array(
        'heading' => "Hoverbox \xE2\x80\x93 $name",
        'save' => ucfirst($tx['action']['save'])
    );
    $labels = array_map('Hoverbox_hsc', $labels);
    $url = "$sn?&amp;hoverbox";
    $editorHeight = $cf['editor']['height'];
    $content = Hoverbox_hsc($content);
    $showSubmit = !function_exists('init_editor')
        || $cf['editor']['external'] == '';
    $bag = compact(
        'labels', 'name', 'url', 'editorHeight', 'content', 'showSubmit'
    );
    $o = Hoverbox_render('edit', $bag);
    init_editor(array('plugintextarea'));
    return $o;
}

function Hoverbox_save($name) {
    global $_Hoverbox;

    Hoverbox_checkCsrfToken();
    $content = stsl($_POST['hoverbox_text']);
    $ok = $_Hoverbox->write($name, $content);
    if ($ok) {
        $qs = '?hoverbox&admin=plugin_main&action=plugin_tx';
        header('Location: ' . HOVERBOX_URL . $qs, true, 303);
        exit;
    } else {
        e('cntsave', 'file', $_Hoverbox->filename($name));
        return Hoverbox_edit($name, $content);
    }
}

function Hoverbox_delete($name) {
    global $_Hoverbox;

    Hoverbox_checkCsrfToken();
    if ($_Hoverbox->delete($name)) {
        $qs = '?hoverbox&admin=plugin_main&action=plugin_tx';
        header('Location: ' . HOVERBOX_URL . $qs, true, 303);
        exit;
    } else {
        e('cntdelete', 'file', $_Hoverbox->filename($name));
        return Hoverbox_admin();
    }
}

function Hoverbox_admin() {
    global $sn, $pth, $tx, $plugin_tx, $_Hoverbox;

    $ptx = $plugin_tx['hoverbox'];
    $labels = array(
        'heading' => "Hoverbox \xE2\x80\x93 $ptx[menu_main]",
        'edit' => ucfirst($tx['action']['edit']),
        'delete' => ucfirst($tx['action']['delete']),
        'create' => $ptx['label_create'],
        'confirm' => addcslashes($ptx['confirm_delete'], "\r\n\\\'")
    );
    $labels = array_map('Hoverbox_hsc', $labels);
    $deleteImage = $pth['folder']['plugins'] . 'hoverbox/images/delete.png';
    $url = $sn . '?&amp;hoverbox';
    $baseURL = $sn . '?&amp;hoverbox&amp;admin=plugin_main&amp;action=';
    $hoverboxs = array();
    foreach ($_Hoverbox->names() as $name) {
        $hoverboxs[$name] = array(
            'editURL' => $baseURL . 'edit&amp;hoverbox_name=' . $name,
            'deleteURL' => $baseURL . 'delete&amp;hoverbox_name=' . $name
        );
    }
    $bag = compact('labels', 'deleteImage', 'url', 'hoverboxs');
    return Hoverbox_render('admin', $bag);
}

if (function_exists('XH_wantsPluginAdministration') && XH_wantsPluginAdministration('hoverbox') || isset($hoverbox) && $hoverbox == 'true'
) {
    $o .= print_plugin_admin('on');
    if (isset($_POST['delete_name'])) {
      $o .= Hoverbox_delete(stsl($_POST['delete_name']));
    }
    switch ($admin) {
    case '':
        $o .= Hoverbox_info();
        break;
    case 'plugin_main':
        switch ($action) {
        case 'new':
            $o .= Hoverbox_new(stsl($_POST['hoverbox_name']));
            break;
        case 'edit':
            $o .= Hoverbox_edit(stsl($_GET['hoverbox_name']));
            break;
        case 'save':
            $o .= Hoverbox_save(stsl($_POST['hoverbox_name']));
            break;
        case 'delete':
            //$o .= Hoverbox_delete(stsl($_POST['delete_name']));
            break;
        case 'data':
            $o .= Hoverbox_data($_POST['hoverbox_name'],$_POST['hoverbox_pic'],$_POST['hoverbox_title'],$_POST['hoverbox_link'],$_POST['hoverbox_linkoption'],$_POST['hoverbox_style'],$_POST['hoverbox_eff']);
            break;
        default:
            $o .= Hoverbox_admin();
        }
        break;
    default:
        $o .= plugin_admin_common($action, $admin, $plugin);
    }
}

function Hoverbox_data($name,$pic,$title,$link,$linkoption,$style,$eff) {
  global $sn, $pth, $tx, $plugin_tx, $_Hoverbox;
  
  $folders[] = $_Hoverbox->getDataFolder();
  foreach ($name as $i => $na) {
    //echo $na.' - '.$title[$i].' - '.$link[$i].' - '.$eff[$i].' ||| ';
    $file = fopen($folders[0].$na.".csv","w");
    fputcsv($file,explode(',',$pic[$i].','.$title[$i].','.$link[$i].','.$linkoption[$i].','.$style[$i].','.$eff[$i]));
    fclose($file);
  }
  $qs = '?hoverbox&admin=plugin_main&action=plugin_tx';
  header('Location: ' . HOVERBOX_URL . $qs, true, 303);
  exit;
}

?>