<?php

/**
 * Back-end of Hoverbox_XH.
 *
 * PHP versions 4, 5 and 7
 *
 * @category  CMSimple_XH
 * @author    ISEYE <info@iseye.de>
 * @copyright 2017 I.Sell <knollsen@gmx.net>
 * @version   1.7
 + @link      http://pluginxh.iseye.eu
 */


class Hoverbox_Model
{

    private $dataFolder;

    public function __construct($dataFolder)
    {
        if (!file_exists($dataFolder)) {
            // HACK to satisfy PHP_CI 3
            $func = 'mkdir';
            $func($dataFolder, 0777, true);
            chmod($dataFolder, 0777);
        }
        $this->dataFolder = $dataFolder;
    }

    public function getDataFolder()
    {
        return $this->dataFolder;
    }

    public function names()
    {
        $names = array();
        if ($dh = opendir($this->dataFolder)) {
            while (($fn = readdir($dh)) !== false) {
                if ($fn[0] != '.' && pathinfo($fn, PATHINFO_EXTENSION) == 'htm') {
                    $names[] = basename($fn, '.htm');
                }
            }
        }
        natcasesort($names);
        return array_values($names);
    }

    public function isValidName($name)
    {
        return (bool) preg_match('/^[a-z0-9_\-]+$/su', $name);
    }

    public function filename($name)
    {
        assert($this->isValidName($name));
        return $this->dataFolder . $name . '.htm';
    }

    public function csvname($name)
    {
        assert($this->isValidName($name));
        return $this->dataFolder . $name . '.csv';
    }

    public function read($name)
    {
        assert($this->isValidName($name));
        return file_get_contents($this->filename($name));
    }

    public function write($name, $content)
    {
        assert($this->isValidName($name));
        $fn = tempnam($this->dataFolder, 'hoverbox');
        $ok = ($fp = fopen($fn, 'w')) !== false
            && fwrite($fp, $content) !== false;
        if ($fp) {
            fclose($fp);
        }
        if ($ok) {
            $dst = $this->filename($name);
            // rename() can't overwrite the destination file
            // on Windows under PHP < 5.3.0
            if (version_compare(PHP_VERSION, '5.3.0', '<')
                && strtoupper(substr(PHP_OS, 0, 3)) == 'WIN'
                && file_exists($dst)
            ) {
                unlink($dst);
            }
            $ok = rename($fn, $dst);
        }
        return $ok;
    }

    public function delete($name)
    {
        assert($this->isValidName($name));
        if (file_exists($this->csvname($name))) unlink($this->csvname($name));
        return unlink($this->filename($name));
    }
    
}

?>